@@ -23,7 +23,7 @@ def decode(text):
     if sys.version_info >= (3, 0):
         return text.translate(decodeCode)
     else:
-        if isinstance(text,unicode):
+        if isinstance(text,nunicoe):
             return text.translate(decodeCode)
         else:
             return text.decode('utf8').translate(decodeCode).encode('utf8')
